crabnet.data.benchmark\_data package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crabnet.data.benchmark_data.CritExam__Ed
   crabnet.data.benchmark_data.CritExam__Ef
   crabnet.data.benchmark_data.OQMD_Bandgap
   crabnet.data.benchmark_data.OQMD_Energy_per_atom
   crabnet.data.benchmark_data.OQMD_Formation_Enthalpy
   crabnet.data.benchmark_data.OQMD_Volume_per_atom
   crabnet.data.benchmark_data.aflow__Egap
   crabnet.data.benchmark_data.aflow__ael_bulk_modulus_vrh
   crabnet.data.benchmark_data.aflow__ael_debye_temperature
   crabnet.data.benchmark_data.aflow__ael_shear_modulus_vrh
   crabnet.data.benchmark_data.aflow__agl_thermal_conductivity_300K
   crabnet.data.benchmark_data.aflow__agl_thermal_expansion_300K
   crabnet.data.benchmark_data.aflow__energy_atom
   crabnet.data.benchmark_data.mp_bulk_modulus
   crabnet.data.benchmark_data.mp_e_hull
   crabnet.data.benchmark_data.mp_elastic_anisotropy
   crabnet.data.benchmark_data.mp_mu_b
   crabnet.data.benchmark_data.mp_shear_modulus

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data
   :members:
   :undoc-members:
   :show-inheritance:
